<?php

namespace Schaffen\Financial\FinancialMovement\Models;

use Illuminate\Database\Eloquent\Model;

class FinancialMovement extends Model
{
    const TIPO_JUROS_SIMPLES = "S";
    const TIPO_JUROS_COMPOSTO = "C";
    const SENTIDO_CREDITO = "C";
    const SENTIDO_DEBITO = "D";
    const STATUS_ABERTO = 0;
    const STATUS_PARCIALMENTE_QUITADO = 1;
    const STATUS_QUITADO = 2;
    const STATUS_ESTORNADO = 3;
    const STATUS_RECEBIDO_CAIXA = 4;
    const STATUS_RECEBIDO_PARCIALMENTE_CAIXA = 5;
    const STATUS_BLOQUEADO_COBRANCA = 6;

    protected $table = "financeiro.movimentacao_financeira";
    protected $primaryKey = "mvf_codigo";
    protected $fillable = ["mvf_data_lancamento", "mvf_sentido", "mvf_valor", "mvf_numero_documento",
        "mvf_descricao", "mvf_dias_protesto", "mvf_multa", "mvf_juros", "mvf_tipo_juros", "mvf_fk_pes_codigo",
        "mvf_fk_pcg_codigo", "mvf_fk_ccu_codigo", "mvf_fk_tpg_codigo", "mvf_fk_his_codigo", "mvf_fk_mvf_codigo",
        "mvf_obs", "mvf_juros_adicionais", "mvf_status", "mvf_num_parcelas", "mvf_data_registro", "mvf_fk_fil_codigo",
        "mvf_fk_cep_codigo", "mvf_vendedor", "mvf_fk_cmf_codigo", "mvf_data_alteracao", "mvf_bloqueio_modulo",
        "mvf_usuario_alteracao", "mvf_usuario_registro", "mvf_codigo_barras","mvf_fk_ent_codigo",
        "mvf_configuracao_cobranca", "mvf_admin", "mvf_fk_fop_codigo", "mvf_validada"];
    public $timestamps = false;

    //Rateios
    public function financial_movement_item() {
        return $this->hasMany(FinancialMovementItem::class, "mfi_fk_mvf_codigo");
    }

    //Parcelas
    public function installment() {
        return $this->hasMany(Installment::class, "par_fk_mvf_codigo");
    }

    //contas corrente

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasManyThrough
     */
    public function current_accounts(){
        return $this->hasManyThrough(
            CurrentAccount::class,
            AssociateCurrentAccountWithFinancialMovement::class,
            "ccm_fk_mvf_codigo",
            "ccr_codigo",
            "mvf_codigo",
            "ccm_fk_ccr_codigo"
        );
    }
}