<?php


namespace Schaffen\Financial\Payment\Services;


use Schaffen\Financial\Payment\DTOs\GeneratePaymentInput;
use Schaffen\Financial\Payment\Exceptions\PaymentException;
use Schaffen\Financial\FinancialMovement\Managers\CurrentAccountManager;

class Discharge
{
    public static function saveCurrentAccounts(GeneratePaymentInput $input, $installment, $paymentValue){
        $ccrItens = [
            "ccr_fk_pcg_codigo" => $input->getPatrimonial(),
            "ccr_data" => $input->getDataPagamento(),
            "ccr_sentido" => $installment->financial_moviment->mvf_sentido
        ];
        $accountManager = app()->make(CurrentAccountManager::class);
        /**
         * Lançamento da Conta Corrente do valor pago da parcela:
         * Valor Parcela = Valor Pago - Juros - Multa - Juros Adicionais - Tarifa Adicional - Valor Moeda + Desconto;
         */
        $ccr_codigos[] = $ccr_codigo = $accountManager->storeOrUpdate(
            [
                "ccr_descricao" => ($installment->financial_moviment->mvf_sentido == 'C' ? '[RECPAR] ' : '[PAGAPAR] ') .
                    (optional($installment->financial_moviment)->mvf_descricao ?? ""),
                "ccr_valor" => $paymentValue
            ] + $ccrItens);
        if(empty($ccr_codigo)){
            throw new PaymentException("Erro ao armazenar o lançamento da conta corrente.");
        }
        if(!empty($input->getJurosAtraso()) || !empty($input->getMulta())){
            /**
             * Lançamento do valor de juros e multa lançados na parcela;
             */
            $ccr_codigos[] = $ccr_codigo = $accountManager->storeOrUpdate(
                [
                    "ccr_descricao" => ($installment->financial_moviment->mvf_sentido == 'C' ? '[RECJUR] ' : '[PAGJUR] ') .
                        (optional($installment->financial_moviment)->mvf_descricao ?? ""),
                    "ccr_valor" =>  $input->getJurosAtraso() + $input->getMulta()
                ] + $ccrItens);
            if(empty($ccr_codigo)){
                throw new PaymentException("Erro ao realizar lançamento da conta corrente de juros/multa de atraso.");
            }
        }
        if(!empty($input->getJurosAdicionais()) || !empty($input->getAdicional()) || !empty($input->getMoeda())){
            /**
             * Lançamento do valor de adicionais lançados na parcela;
             */
            $ccr_codigos[] = $ccr_codigo = $accountManager->storeOrUpdate(
                [
                    "ccr_descricao" => ($installment->financial_moviment->mvf_sentido == 'C' ? '[RECADC] ' : '[PAGADC] ') .
                        (optional($installment->financial_moviment)->mvf_descricao ?? ""),
                    "ccr_valor" =>  $input->getDesconto()
                ] + $ccrItens);
            if(empty($ccr_codigo)){
                throw new PaymentException("Erro ao realizar lançamento dos valores adicionais de parcela.");
            }
        }
        if(!empty($input->getDesconto())){
            /**
             * Lançamento do valor de desconto lançado na parcela;
             */
            $ccr_codigos[] = $ccr_codigo = $accountManager->storeOrUpdate(
                [
                    "ccr_descricao" => ($installment->financial_moviment->mvf_sentido == 'C' ? '[RECDES] ' : '[PAGDES] ') .
                        (optional($installment->financial_moviment)->mvf_descricao ?? ""),
                    "ccr_sentido" => $installment->financial_moviment->mvf_sentido == "C" ? "D" : "C",
                    "ccr_valor" =>  $input->getJurosAdicionais() + $input->getAdicional() + $input->getMoeda()
                ] + $ccrItens);
            if(empty($ccr_codigo)){
                throw new PaymentException("Erro ao realizar lançamento da conta corrente de desconto.");
            }
        }
        return $ccr_codigos;
    }
}